import pymongo
import sys
import ssl

import database.db_credentials as db

class MongoDatabase(object):

    def __init__(self, environment):
        self.environment = environment
        self.mongo_credentials = db.mongo_credentials(environment)

    def connect(self):
        self.conn = pymongo.MongoClient(
            self.mongo_credentials["uri"],
            ssl=self.mongo_credentials["ssl"],
            ssl_cert_reqs=ssl.CERT_NONE
        )

        self.db = self.conn['bi']
        sys.stdout.flush()

    def close_connection(self):
        self.conn.close()

        sys.stdout.flush()
    



import os
from pathlib import Path
from setuptools import setup


def read(file_name):
    with open(os.path.join(Path(os.path.dirname(__file__)), file_name)) as _file:
        return _file.read()


long_description = read('README.md')

setup(
    name='nkia',
    version='0.0.6',
    description='This is a module to predict the products category using artificial inteligence.',
    url='https://bitbucket.org/nksistemasdeinformacao/servicos-biodigital/src/master/',
    download_url='https://bitbucket.org/nksistemasdeinformacao/servicos-biodigital/src/master/',
    license='Apache License 2.0',
    author='NK Sistemas de Informacao em Saude',
    author_email='ti@nkodontologia.com.br',

    py_modules=['nkia'],
    package_dir={'': 'src'},

    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords=['tensorflow', 'nlp', 'nk',
              'python3', 'python-3', 'food-products'],
    classifiers=[
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Topic :: Communications :: Email',
    ],
    python_requires='>=3.6',
    install_requires=[
    ],
    extras_require={
        'dev': [
            'pytest>=3.7'
        ]
    }
)


import sys
from neo4j import GraphDatabase

import database.db_credentials as db

class Neo4jDatabase(object):

    def __init__(self, environment):
        self.environment = environment
        self.neo4j_credentials = db.neo4j_credentials(environment)

    def connect(self):   
        complete_host = 'bolt://' + self.neo4j_credentials['host'] + ':' + str(self.neo4j_credentials['port'])

        driver = GraphDatabase.driver(complete_host, auth=(self.neo4j_credentials['user'], self.neo4j_credentials['passwd']))

        return driver

    def match(self, query, driver, params=None):
        with driver.session() as session:
            result = session.read_transaction(self.execute_query, query, params)

        driver.close()
        
        return result

    def execute_query(self, tx, query, params):
        if params != None:
            query_result = tx.run(query, params)
        else:
            query_result = tx.run(query)

        response = [result for result in query_result]

        return response